@@ -518,7 +518,7 @@ sub parse {
   my %idx = ();
   my $at_end = 0;
 
-  local $_;
+  local *_;
   while (<$rd>) {
     s/[\015\012]+$//;
     if (m/^:?($PARSE_RE__token):\s+(.*)$/o)	# $1 -- name	$2 -- value
